game_qu API documentation

# Package `game_qu`

## Sub-modules

`game_qu.base`

  This module holds nearly everything that is not either math or part of the gui. It holds a way to work with the keyboard, utility functions, events, etc.

`game_qu.getting_started`
`game_qu.gui_components`

  This module has many GUI components (buttons, screens, etc.)

`game_qu.library_abstraction`

  This file holds the module variables that the game engine will be getting its functions and constants from (either pygame or pyglet)

`game_qu.math`

  This module has all the game engine math classes (functions, derivatives, vectors, etc.)

`game_qu.paths`

  This module holds many path classes. A path is defined by some function of time that moves an object along the designated path.

`game_qu.pygame_abstraction`

  Holds all the code that abstracts dealing with pygame code from the rest of the game engine code. It does this by having an interface with many …

`game_qu.pyglet_abstraction`

  Holds all the code that abstracts dealing with pyglet code from the rest of the game engine code. It does this by having an interface with many …